@@ -5,6 +5,8 @@ from collections import Counter
 import matplotlib.pyplot as plt
 from spacy import util as util
 import subprocess
+from datetime import datetime
+
 
 ngram_vars={
     "nlp":"",
@@ -82,7 +84,7 @@ def calculateDist(dataset,group_by="month"):
     sophia2_ngram_struct = {}
     if group_by == "day":
         for key, ds in gb_dataset:
-            sophia2_ngram_struct[key.strftime("%Y/%m/%d")] = get_frequency(ds)
+            sophia2_ngram_struct[datetime.strptime(key, '%Y-%m-%d').strftime("%Y/%m/%d")] = get_frequency(ds)
     elif group_by == "month":
         for (month,year), ds in gb_dataset:
             sophia2_ngram_struct[(str(year)+"/"+str(month))] = get_frequency(ds)
